
/*
 * This file defines a standard AI personality for the base game. 
 * 
 * It relies on ruleset definition in /rulesets/ to provide
 * standard strategy descriptions and necessary game stat information.
 * 
 * Then it passes control to the main code.
 * 
 */

// You can redefine these paths when you make a customized AI
// for a map or a challenge.
NB_PATH = "/multiplay/skirmish/";
NB_INCLUDES = NB_PATH + "nb_includes/";
NB_RULESETS = NB_PATH + "nb_rulesets/";
NB_COMMON = NB_PATH + "nb_common/";

// please don't touch this line
include(NB_INCLUDES + "_head.js");

////////////////////////////////////////////////////////////////////////////////////////////
// Start the actual personality definition

// the rules in which this personality plays
include(NB_RULESETS + "standard.js");
include(NB_COMMON + "standard_build_order.js");

// variables defining the personality
var subpersonalities = {
	MR: {
		chatalias: "mr",
		weaponPaths: [ // weapons to use; put late-game paths below!
			weaponStats.rockets_AT, 
			weaponStats.machineguns, 
			weaponStats.rockets_AS, 
			weaponStats.rockets_AA, 
			weaponStats.rockets_Arty,
		],
		earlyResearch: [ // fixed research path for the early game
			"R-Wpn-MG-Damage01",
			"R-Vehicle-Prop-Halftracks",
			"R-Struc-PowerModuleMk1",
			"R-Wpn-MG3Mk1",
		],
		minTanks: 1, becomeHarder: 2, maxTanks: 20,
		minTrucks: 4, minHoverTrucks: 1, maxSensors: 2,
		minMiscTanks: 1, maxMiscTanks: 30,
		vtolness: 85, defensiveness: 50,
		maxPower: 250,
		repairAt: 5,
	},
	MC: {
		chatalias: "mc",
		weaponPaths: [
			weaponStats.cannons, 
			weaponStats.machineguns, 
			weaponStats.mortars,
                        weaponStats.fireMortars,
			weaponStats.cannons_AA,
		],
		earlyResearch: [
			"R-Wpn-MG-Damage01",
			"R-Vehicle-Prop-Halftracks",
			"R-Wpn-Cannon1Mk1",
			"R-Struc-PowerModuleMk1",
			"R-Wpn-MG3Mk1",
		],
		minTanks: 1, becomeHarder: 2, maxTanks: 20,
		minTrucks: 4, minHoverTrucks: 1, maxSensors: 2,
		minMiscTanks: 1, maxMiscTanks: 30,
		vtolness: 85, defensiveness: 50,
		maxPower: 250,
		repairAt: 5,
	},
	FR: {
		chatalias: "fr",
		weaponPaths: [
			weaponStats.rockets_AT, 
			weaponStats.rangedFlamers,
			weaponStats.fireMortars,
                        weaponStats.rockets_Arty,
			weaponStats.rockets_AA,
			weaponStats.lasers,
		],
		earlyResearch: [
			"R-Wpn-Flamer-ROF01",
			"R-Vehicle-Prop-Halftracks",
			"R-Struc-PowerModuleMk1",
                        "R-Vehicle-Prop-Hover",
		],
		minTanks: 1, becomeHarder: 2, maxTanks: 20,
		minTrucks: 4, minHoverTrucks: 1, maxSensors: 2,
		minMiscTanks: 1, maxMiscTanks: 30,
		vtolness: 85, defensiveness: 50,
		maxPower: 250,
		repairAt: 5,
	},
	FC: {
		chatalias: "fc",
		weaponPaths: [
			weaponStats.cannons, 
			weaponStats.rangedFlamers,
                        weaponStats.mortars,
			weaponStats.fireMortars,
			weaponStats.cannons_AA,
			weaponStats.lasers,
		],
		earlyResearch: [
			"R-Wpn-Flamer-ROF01",
			"R-Vehicle-Prop-Halftracks",
			"R-Wpn-Cannon1Mk1",
			"R-Struc-PowerModuleMk1",
		],
		minTanks: 1, becomeHarder: 2, maxTanks: 20,
		minTrucks: 4, minHoverTrucks: 1, maxSensors: 2,
		minMiscTanks: 1, maxMiscTanks: 30,
		vtolness: 85, defensiveness: 50,
		maxPower: 250,
		repairAt: 5,
	},
};

// this function describes the early build order
// you can rely on personality.chatalias for choosing different build orders for
// different subpersonalities
function buildOrder() {
	// Only use this build order in early game, on standard difficulty, in T1 no bases.
	// Otherwise, fall back to the safe build order.
	if (gameTime > 300000 || difficulty === INSANE
	                      || isStructureAvailable("A0ComDroidControl") || baseType !== CAMP_CLEAN)
		return buildOrder_StandardFallback();
	if (personality.chatalias === "fc" || personality.chatalias == "fr") {
		if (buildMinimum(structures.labs, 1)) return true;
		if (buildMinimum(structures.factories, 1)) return true;
		if (buildMinimum(structures.labs, 2)) return true;
		if (buildMinimum(structures.factories, 2)) return true;
		if (buildMinimumDerricks(3)) return true;
		if (buildMinimum(structures.hqs, 1)) return true;
		if (buildMinimum(structures.gens, 2)) return true;
	} else {
		if (buildMinimum(structures.factories, 2)) return true;
		if (buildMinimumDerricks(3)) return true;
		if (buildMinimum(structures.labs, 1)) return true;
		if (buildMinimum(structures.hqs, 1)) return true;
		if (buildMinimum(structures.factories, 3)) return true;
		if (buildMinimum(structures.gens, 2)) return true;
                if (buildMinimum(structures.labs, 2)) return true;
	}
	return captureSomeOil();
}



////////////////////////////////////////////////////////////////////////////////////////////
// Proceed with the main code

include(NB_INCLUDES + "_main.js");
