
/*
 * This file defines a standard AI personality for the base game. 
 * 
 * It relies on ruleset definition in /rulesets/ to provide
 * standard strategy descriptions and necessary game stat information.
 * 
 * Then it passes control to the main code.
 * 
 */

// You can redefine these paths when you make a customized AI
// for a map or a challenge.
NB_PATH = "/multiplay/skirmish/";
NB_INCLUDES = NB_PATH + "nb_includes/";
NB_RULESETS = NB_PATH + "nb_rulesets/";
NB_COMMON = NB_PATH + "nb_common/";

// please don't touch this line
include(NB_INCLUDES + "_head.js");

////////////////////////////////////////////////////////////////////////////////////////////
// Start the actual personality definition

// the rules in which this personality plays
include(NB_RULESETS + "standard.js");
include(NB_COMMON + "standard_build_order.js");

// variables defining the personality
var subpersonalities = {
	M: {
		chatalias: "m",
		weaponPaths: [
			weaponStats.cybmachineguns, 
			weaponStats.cybrailguns,
		],
		earlyResearch: [
			"R-Defense-Tower01",
			"R-Struc-Factory-Cyborg",
			"R-Struc-PowerModuleMk1",
			"R-Wpn-MG-Damage03",
		],
		minTanks: 5, becomeHarder: 5, maxTanks: 50,
		minTrucks: 3, minHoverTrucks: 4, maxSensors: 1,
		minMiscTanks: 1, maxMiscTanks: 3,
		vtolness: 45, defensiveness: 45,
		maxPower: 700,
		repairAt: 75,
	},
	F: {
		chatalias: "f",
		weaponPaths: [
			weaponStats.cybflamers, 
			weaponStats.cyblasers, 
		],
		earlyResearch: [
                        "R-Struc-Factory-Cyborg",
			"R-Wpn-Flamer-ROF01",
			"R-Struc-PowerModuleMk1",
		],
		minTanks: 5, becomeHarder: 5, maxTanks: 50,
		minTrucks: 3, minHoverTrucks: 4, maxSensors: 1,
		minMiscTanks: 1, maxMiscTanks: 3,
		vtolness: 45, defensiveness: 45,
		maxPower: 700,
		repairAt: 75,
	},

};

// this function describes the early build order
// you can rely on personality.chatalias for choosing different build orders for
// different subpersonalities
function buildOrder() {
	// Only use this build order in early game, on standard difficulty, in T1 no bases.
	// Otherwise, fall back to the safe build order.
	if (gameTime > 450000 || difficulty === INSANE
	                      || isStructureAvailable("A0ComDroidControl") || baseType !== CAMP_CLEAN)
		return buildOrder_StandardFallback();
	if (buildMinimum(structures.labs, 2)) return true;
	if (buildMinimum(structures.factories, 1)) return true;
	if (buildMinimum(structures.labs, 3)) return true;
	if (buildMinimumDerricks(2)) return true;
	if (buildMinimum(structures.hqs, 1)) return true;
	if (buildMinimum(structures.gens, 2)) return true;
        if (buildMinimum(structures.templateFactories, 2)) return true;
	return captureSomeOil();
}



////////////////////////////////////////////////////////////////////////////////////////////
// Proceed with the main code

include(NB_INCLUDES + "_main.js");
