
/*
 * This file defines a standard AI personality for the base game. 
 * 
 * It relies on ruleset definition in /rulesets/ to provide
 * standard strategy descriptions and necessary game stat information.
 * 
 * Then it passes control to the main code.
 * 
 */

// You can redefine these paths when you make a customized AI
// for a map or a challenge.
NB_PATH = "/multiplay/skirmish/";
NB_INCLUDES = NB_PATH + "nb_includes/";
NB_RULESETS = NB_PATH + "nb_rulesets/";
NB_COMMON = NB_PATH + "nb_common/";

// please don't touch this line
include(NB_INCLUDES + "_head.js");

////////////////////////////////////////////////////////////////////////////////////////////
// Start the actual personality definition

// the rules in which this personality plays
include(NB_RULESETS + "standard.js");
include(NB_COMMON + "standard_build_order.js");

// variables defining the personality
var subpersonalities = {
	FR: {
		chatalias: "fr",
		weaponPaths: [
			weaponStats.rockets_AT,
                        weaponStats.rockets_Arty,
			weaponStats.flamers,
			weaponStats.rockets_AS,
			weaponStats.rockets_AA,
			weaponStats.lasers,
		],
		earlyResearch: [
                        "R-Defense-Pillbox01",
			"R-Wpn-MG3Mk1",
                        "R-Wpn-Flamer01Mk1",
                        "R-Defense-WallTower01",
			"R-Vehicle-Prop-Halftracks",
			"R-Struc-PowerModuleMk1",
                        "R-Wpn-Rocket02-MRL",
                        "R-Wpn-Rocket01-LtAT",
		],
		minTanks: 2, becomeHarder: 4, maxTanks: 30,
		minTrucks: 5, minHoverTrucks: 5, maxSensors: 1,
		minMiscTanks: 1, maxMiscTanks: 2,
		vtolness: 90, defensiveness: 60,
		maxPower: 1600,
		repairAt: 10,
	},
	CR: {
		chatalias: "cr",
		weaponPaths: [
			weaponStats.rockets_AT,
                        weaponStats.rockets_Arty,
			weaponStats.cannons_AA, 
			weaponStats.rockets_AS,
			weaponStats.cannons,
			weaponStats.lasers,
		],
		earlyResearch: [
			"R-Defense-Pillbox01",
			"R-Wpn-MG3Mk1",
                        "R-Defense-WallTower01",
			"R-Vehicle-Prop-Halftracks",
			"R-Struc-PowerModuleMk1",
                        "R-Wpn-Rocket02-MRL",
                        "R-Wpn-Flamer01Mk1",
                        "R-Struc-VTOLPad-Upgrade01",
                        "R-Wpn-Rocket01-LtAT",
			"R-Wpn-Cannon1Mk1",
		],
		minTanks: 2, becomeHarder: 4, maxTanks: 30,
		minTrucks: 5, minHoverTrucks: 5, maxSensors: 1,
		minMiscTanks: 1, maxMiscTanks: 2,
		vtolness: 90, defensiveness: 60,
		maxPower: 1600,
		repairAt: 10,
	},
};

// this function describes the early build order
// you can rely on personality.chatalias for choosing different build orders for
// different subpersonalities
function buildOrder() {
	// Only use this build order in early game, on standard difficulty, in T1 no bases.
	// Otherwise, fall back to the safe build order.
	if (gameTime > 450000 || difficulty === INSANE
	                      || isStructureAvailable("A0ComDroidControl") || baseType !== CAMP_CLEAN)
		return buildOrder_StandardFallback();
	if (buildMinimum(structures.factories, 1)) return true;
	if (buildMinimum(structures.labs, 2)) return true;
        if (buildMinimumDerricks(4)) return true;
	if (buildMinimum(structures.hqs, 1)) return true;
        if (buildMinimum(structures.gens, 2)) return true;
	if (buildMinimum(structures.factories, 2)) return true;
	return captureSomeOil();
}



////////////////////////////////////////////////////////////////////////////////////////////
// Proceed with the main code

include(NB_INCLUDES + "_main.js");
